==> core-react-0.8.0.tgz: package/es/Tabs/TabList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import Button from '../Button';
import Tab from './Tab';

var TabList = /*#__PURE__*/function (_React$Component) {
  _inherits(TabList, _React$Component);

  function TabList(props) {
    var _this;

    _classCallCheck(this, TabList);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(TabList).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleAddNewTab", function (e) {
      e.preventDefault();
      var id = Math.random().toString(16).slice(2, 6);
      var newTab = _this.props.newTab;
      var children = _this.state.children;
      var newTabElement = React.createElement(Tab, {
        key: id,
        closeable: newTab.closeable || false
      }, newTab.name);

      _this.context.tabs.setState({
        activeIndex: _this.context.tabs.tabCount
      });

      _this.context.tabs.tabCount = _this.context.tabs.panelCount = 0;

      _this.setState({
        children: children.concat(newTabElement)
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onClose", function (index, activeKey) {
      var children = _this.state.children;

      _this.setState({
        children: children.filter(function (c) {
          return children.indexOf(c) !== index;
        })
      });

      _this.context.tabs.changeActiveIndex(children.length - 2);
    });

    _this.state = {
      children: props.children
    };
    return _this;
  }

  _createClass(TabList, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        tablist: this
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          newTab = _this$props.newTab,
          other = _objectWithoutProperties(_this$props, ["className", "newTab"]);

      return React.createElement("ul", _extends({
        className: cx("".concat("waui", "-tabs__list"), className)
      }, other), this.props.children, !!newTab && React.createElement(Button, {
        size: "sm",
        icon: "add",
        onClick: this.handleAddNewTab
      }));
    }
  }]);

  return TabList;
}(React.Component);

TabList.childContextTypes = {
  tablist: PropTypes.instanceOf(TabList)
};
TabList.contextTypes = {
  tabs: PropTypes.object
};
TabList.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The definition of new tab */
  newTab: PropTypes.shape({
    name: PropTypes.string.isRequired,
    id: PropTypes.string,
    closeable: PropTypes.bool
  })
};
export default TabList;

==> core-react-0.8.2.tgz: package/es/Tabs/TabList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import Button from '../Button';
import Tab from './Tab';

var TabList = /*#__PURE__*/function (_React$Component) {
  _inherits(TabList, _React$Component);

  function TabList(props) {
    var _this;

    _classCallCheck(this, TabList);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(TabList).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleAddNewTab", function (e) {
      e.preventDefault();
      var id = Math.random().toString(16).slice(2, 6);
      var newTab = _this.props.newTab;
      var children = _this.state.children;
      var newTabElement = /*#__PURE__*/React.createElement(Tab, {
        key: id,
        closeable: newTab.closeable || false
      }, newTab.name);

      _this.context.tabs.setState({
        activeIndex: _this.context.tabs.tabCount
      });

      _this.context.tabs.tabCount = _this.context.tabs.panelCount = 0;

      _this.setState({
        children: children.concat(newTabElement)
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onClose", function (index, activeKey) {
      var children = _this.state.children;

      _this.setState({
        children: children.filter(function (c) {
          return children.indexOf(c) !== index;
        })
      });

      _this.context.tabs.changeActiveIndex(children.length - 2);
    });

    _this.state = {
      children: props.children
    };
    return _this;
  }

  _createClass(TabList, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        tablist: this
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          newTab = _this$props.newTab,
          other = _objectWithoutProperties(_this$props, ["className", "newTab"]);

      return (/*#__PURE__*/React.createElement("ul", _extends({
          className: cx("".concat("waui", "-tabs__list"), className)
        }, other), this.props.children, !!newTab && /*#__PURE__*/React.createElement(Button, {
          size: "sm",
          icon: "add",
          onClick: this.handleAddNewTab
        }))
      );
    }
  }]);

  return TabList;
}(React.Component);

TabList.childContextTypes = {
  tablist: PropTypes.instanceOf(TabList)
};
TabList.contextTypes = {
  tabs: PropTypes.object
};
TabList.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The definition of new tab */
  newTab: PropTypes.shape({
    name: PropTypes.string.isRequired,
    id: PropTypes.string,
    closeable: PropTypes.bool
  })
};
export default TabList;
